import { Button, Popup } from "vant";
import { } from "vant";
import { defineComponent, nextTick, onMounted, reactive, ref, watch } from "vue";
import styles from "./index.module.less";
import { getImage } from "./images";
import { useRect } from "@vant/use";

export default defineComponent({
  name: "woring",
  emits: ["close"],
  setup(props, { emit }) {
    const data = reactive({
      box: {},
      show: false,
      steps: [
        {
          ele: "",
          eleRect: {} as DOMRect,
          img: getImage("woring1.png"),
          handStyle: {
            top: "2.7rem",
            left:'4.5rem'
          },
          imgStyle: {
            top: "3.3rem",
            left:'2.1rem'
          },
          btnsStyle: {
            top: "6.2rem",
            left:'3.5rem'
          },
        },
        {
          ele: "",
          eleRect: {} as DOMRect,
          img: getImage("woring2.png"),
          handStyle: {
            top: "2.7rem",
            left:'4.5rem'
          },
          imgStyle: {
            top: "3.3rem",
            left:'2.1rem'
          },
          btnsStyle: {
            top: "6.2rem",
            left:'3.5rem'
          },
        },
        {
          ele: "",
          img: getImage("woring3.png"),
          handStyle: {
            top: "-1.43rem",
            left:'4.5rem',
            transform: 'rotate(180deg)'
          },
          imgStyle: {
            top: "-5.4rem",
            left:'2.1rem'
          },
          btnsStyle: {
            top: "-2.4rem",
            left:'2.5rem'
          },
        },
      ],
      step: 0,
    });
    const tipShow = ref(false)

    const getStepELe = () => {

      const ele: HTMLElement = document.getElementById(`woring-${data.step}`)!;
      if (ele) {
        const eleRect = ele.getBoundingClientRect();
        data.box = {
          left: eleRect.x + "px",
          top: eleRect.y + "px",
          width: eleRect.width + "px",
          height: eleRect.height + "px",
        };
      }
    };
    onMounted(() => {
      setTimeout(()=>{
        const guideInfo = localStorage.getItem('guideInfo')
        if(guideInfo&&JSON.parse(guideInfo).woring){
         tipShow.value =false
        }else {
         tipShow.value =true
        }
        getStepELe();
      },300)

    });

    const handleNext = () => {
      if (data.step >= 3) {
       endGuide();
        return;
      }
      data.step = data.step + 1;
      getStepELe();
    };

    const endGuide = ()=>{
      let guideInfo = JSON.parse(localStorage.getItem('guideInfo') || '{}')

      if(!guideInfo){
        guideInfo = {woring:true}
      }else{
        guideInfo.woring = true
      }
      localStorage.setItem('guideInfo',JSON.stringify(guideInfo))
      tipShow.value = false
    //  localStorage.setItem('endC')
    }
    return () => (
      <Popup teleport="body" overlay={false} closeOnClickOverlay={false} class={["popup-custom", styles.guidePopup]} v-model:show={tipShow.value}>
      <div class={styles.content} onClick={() => handleNext()}>
        <div
          class={[styles.backBtn,styles.right]}
          onClick={(e: Event) => {
            e.stopPropagation();
           endGuide()
          }}
        >
          跳过
        </div>
        <div class={styles.box} style={data.box} id={`modeType-${data.step}`}>
          {data.steps.map((item: any, index) => (

            <div
              onClick={(e: Event) => e.stopPropagation()}
              class={styles.item}
              style={{
                display: index === data.step ? "" : "none",
                left: `${item.eleRect?.left}px`,
                top: `${item.eleRect?.top}px`,
              }}
            >
              <img class={styles.img} style={item.imgStyle} src={item.img} />
              <img class={styles.iconHead} style={item.handStyle} src={getImage("indexDot.png")} />
              <div class={styles.btns} style={item.btnsStyle}>
                {data.step + 1 == data.steps.length ? (
                  <>
                    <Button
                      class={styles.btn}
                      round
                      color="transparent"
                      style={{ "border-color": "#fff" }}
                      type="primary"
                      onClick={() => {
                        data.step = 0;
                        getStepELe();
                      }}
                    >
                      再看一遍
                    </Button>
                    <Button class={[styles.btn,styles.endBtn]} round type="primary" onClick={() =>endGuide()}>
                      完成
                    </Button>
                  </>
                ) : (
                  <Button class={styles.btn} round type="primary" onClick={() => handleNext()}>

                    下一步 ({data.step + 1}/{data.steps.length})
                  </Button>
                )}
              </div>
            </div>
          ))}
        </div>
      </div>
      </Popup>
    );
  },
});
